@@ -5,7 +5,6 @@ from pathlib import Path
 from PIL import Image
 from tqdm.auto import tqdm
 
-
 try:
     import pyvips
 
@@ -20,12 +19,21 @@ except pyvips.error.Error:
 SUPPORTED_FORMATS = {"jpg", "webp", "png"}
 
 
-# Updated ImageResizer class
+# Updated UniResizer class
+
+"""
+@@@@@@@@@@@@@@@@
+
+DEPRECIATED: use uni_resizer.py instead
+
+@@@@@@@@@@@@@@@@
+"""
 
 class ImageResizer:
-    def __init__(self, src_dir: str, dst_dir: str, min_side: int = 768, format: str = "webp", quality: int = 95, exist_ok: bool = False):
+    def __init__(self, src_dir: str, dst_dir: str, min_side: int = 768, format: str = "webp", quality: int = 95,
+                 exist_ok: bool = False):
         """
-        Initialize an instance of ImageResizer.
+        Initialize an instance of UniResizer.
         """
         self.src_dir = Path(src_dir)
         self.dst_dir = Path(dst_dir)
@@ -47,10 +55,13 @@ class ImageResizer:
         """
         Resize a single image and save the result.
         """
-        dst_path = self.dst_dir / relative_path.with_suffix(f".{self.format}")
+        # dst_path = self.dst_dir / relative_path.with_suffix(f".{self.format}")
+
+        # new:
+        rel_dst_path = relative_path.with_name(relative_path.stem + "_resized").with_suffix(f".{self.format}")
 
         # Ensure the destination directory exists
-        dst_path.parent.mkdir(parents=True, exist_ok=True)
+        rel_dst_path.parent.mkdir(parents=True, exist_ok=True)
 
         if HAS_PYVIPS:
             image = self._resize_with_pyvips(file_path)
@@ -64,7 +75,7 @@ class ImageResizer:
             else:
                 image = Image.open(file_path)
 
-        self._save_image(image, dst_path)
+        self._save_image(image, rel_dst_path)
 
     def _resize_with_pil(self, image_path: Path) -> Image:
         """
@@ -110,6 +121,11 @@ class ImageResizer:
         self._resize_image(file_path, relative_path)
 
     def _save_image(self, image, dst_path: Path):
+        """
+        Save an image in the specified format.
+        :param image: PIL.Image or pyvips.Image
+        :param dst_path: Path (route/new_name.webp)
+        """
         """
         Save an image in the specified format.
         """
@@ -137,6 +153,20 @@ class ImageResizer:
             list(tqdm(concurrent.futures.as_completed(futures), total=len(tasks),
                       desc=f"Resizing images to min_side={self.min_side}"))
 
+
+    def resize_single_image(self, image_path: str):
+        """
+        Resize a single image and save the result next to the original image with "_resized" in the name.
+        """
+        file_path = Path(image_path)
+        relative_path = file_path.name
+        # Add "_resized" before the file extension
+        resized_name = relative_path.stem + "_resized" + relative_path.suffix
+        relative_resized_path = file_path.parent / resized_name
+
+        self._resize_image(file_path, relative_resized_path)
+
+
     def resize_images(self):
         """
         Resize all supported images in the source directory.
@@ -176,10 +206,10 @@ if __name__ == "__main__":
     src_dir = input("dir path:")
 
     dst_dir = f"{src_dir}_768webp"
-    min_side = 64
+    min_side = 1024
 
-    # Create an instance of the ImageResizer class
+    # Create an instance of the UniResizer class
     resizer = ImageResizer(src_dir, dst_dir, min_side)
 
     # Get a list of image files from the source directory
-    resizer.resize_images()
\ No newline at end of file
+    resizer.resize_images()
